<!-- posts menu -->
  <div class="subnav">
      <ul class="nav nav-pills">
          {% for post in site_content.posts.object_list %}

          <li class=""><a href="#{{ post.title|slugify }}">{{ post.title }}</a></li>
      
          {% endfor %}
    </ul>
  </div>
</header>
    

{% for post in site_content.posts.object_list %}

<section id="{{ post.title|slugify }}">
  <div class="page-header">
      <h1><a href="{{ post.get_url }}">{{ post.title }}</a></h1>
  </div>
  
  {{ post.content|safe }}



        {% if post.comments %}

        <!--<div class="page_post_comments">

            <a href='{{ post.get_url }}#comments'>
                {{ post.comment_set.count }} comments
            </a>

        </div>-->

        {% endif %}
        
</section>

{% endfor %}


{% if site_content.posts.has_other_pages %}

  <div class="pagination pagination-centered">
      <ul>
        {% for page in site_content.posts.paginator.page_range %}
        <li class="{% if site_content.posts.number == page %}active{% else %}#{% endif %}">
        <a href="/{{ site_content.current_language.country_code }}/{{ site_content.page.link.url }}~{{ page }}">
            {{ page }}
        </a></li>
        {% endfor %}
    </ul>
  </div>

{% endif %}
