"""
This project will give you the power of standard CMS
(content management system) like Drupal, Joomla, WordPress but with much
more speed and simplicity.

It may not have as much plugins and templates like WordPress but it is super
simple application with django admin with WYSIWYG editors for page and post
editing.

It is designed for easy web content editing with no previous experience in
HTML or CSS. Just install it once, use default template or create one for
yourself (or hire someone to make it) and use it. There is no maintenance
required.
"""

VERSION = '1.2.2'
