<!DOCTYPE html>

<!--

This template is licenced by Apache v2.0 licence.

Source: http://bootswatch.com/default/

The template was modified to work with django-pages application.

-->

<html>
    <head>
        <meta http-equiv="content-type" content="text/html; charset=UTF-8">
        <meta charset="utf-8">


        {% include 'default3/base_metadata.html' %}

        {% include 'default3/base_title.html'%}

        <meta name="viewport" content="width=device-width, initial-scale=1.0">

        <!--[if lt IE 9]>
            <script src="http://html5shim.googlecode.com/svn/trunk/html5.js"></script>
        <![endif]-->

        {% include 'default3/base_static.html' %}    

    </head>

    <body style="margin-top: 0px;" class="preview" id="top" data-spy="scroll" data-target=".subnav" data-offset="80">
   
        <div class="navbar navbar-fixed-top">
            <div class="navbar-inner">
                <div class="container">

        {% include 'default2/base_header.html' %}

    <div class="container">
    {% block content %}    

    {% endblock %}
		
    
    <br><br><br><br>

     <!-- Footer
      ================================================== -->
      <hr>

      <footer id="footer">
        <p class="pull-right"><a href="#top">Back to top</a></p>
  
            {{ site_content.site.footer|safe }}

        </footer>

    </div><!-- /container -->

    <!-- Scripts -->
    {% for script in site_content.scripts %}
        
        <!-- {{ script.name }} --> 
        {{ script.code|safe }}

    {% endfor %}
    <!-- end scripts -->

</body></html>
